#!/usr/bin/python

import messages

class XenLab:
	
	# __init__ #{{{
	#
	# arguments
	# path		path to the lab directory, from main.cfg
	#
	def __init__(self, path):
		
		# initialize variables
		self.labPath = path
		self.classNo = None
		self.labNo = None
		self.className = ''
		self.labName = ''
		self.instructor = ''
		# self.world = None

		# meta variables
		self.labMetaData = {}
		self.groups = {}
		self.userList = []

		# initalize variables
		self.initVariablesFromConfigFiles()
#}}}
	# __str__#{{{
	# for debugging purposes only
	def __str__(self):
		return "Path: %s\nClass %s, Lab %s" \
				% (self.labPath, self.classNo, self.labNo)
#}}}
	# initVariablesFromConfigFiles(self)#{{{
	# read and store data from lab.cfg and groups.cfg
	def initVariablesFromConfigFiles(self):
		
		# open configuration files, parse, and store data
		self.labData = self.parseLabConfigFile\
				(open(self.labPath + "/" + "lab.cfg", 'r'))
		self.groupData = self.parseLabConfigFile\
				(open(self.labPath + "/" + "groups.cfg", 'r'))

		# build dictionaries from lab and groups config files
		for item in self.labData:
			kv = item.split("=")
			self.labMetaData[kv[0]] = kv[1]

		for item in self.groupData:
			kv = item.split(":")
			self.groups[kv[0]] = kv[1].split(",")

		# Build list of all users for this lab
		# Will make initial menu building easier
		for group in self.groups:
			for user in self.groups[group]:
				self.userList.append(user)
				
		# set variables for metadata
                # classNo and labNo are required
		self.classNo = self.labMetaData['classno']
		self.labNo = self.labMetaData['labno']
                # these are optional
                if 'classname' in self.labMetaData.keys():
                    self.className = self.labMetaData['classname'] 
                if 'labname' in self.labMetaData.keys():
		    self.labName = self.labMetaData['labname'] 
                if 'instructor' in self.labMetaData.keys():
                    self.instructor = self.labMetaData['instructor'] 
	#}}}
	def parseLabConfigFile(self, f):#{{{
		'''Parse the lines in a file object f, discarding comments and blank
		lines. Return all other lines in a list.
		'''
		lines = []
		for line in f.readlines():
			if line.startswith("#"):
				pass
			elif line.startswith("\n"):
				pass
			else:
				lines.append(line.strip())

		return lines
#}}}
	# isUser(self, user)#{{{
	# asks if user is a member of any of the groups in this lab
	# Assumes no member is in more than one group.
	def isUser(self, user):
		userSet = set(self.userList)
		if user in userSet:
			return True
		else:
			return False

#}}}
	# getUserGroup(self, user)#{{{
	# returns user's group # for this lab
	def getUserGroup(self, user):
		for group in self.groups:
			if user in self.groups.get(group):
				return group
	#}}}
	# getUserData(self, user)#{{{
	# returns tuple: class#, lab#, group#
	# note: deprecated
	def getUserData(self, user):
		if self.isUser(user):
			# return tuple of class,lab,group
			return self.classNo, self.labNo, self.getUserGroup(user)
		else:
			messages.error("User %s not a member of this lab %s" \
					% (user,self.classNo+"-"+self.labNo))
#}}}
# main()#{{{
# for debugging purposes only
def main():
	# pathname must be absolute
	#labdir = '/home/xenlabs/labs/cs343/lab0' 
        labdir = '/home/xenlabs/labs/test'
	test = XenLab(labdir)
	print test
	print test.isUser('grobinso')

if __name__ == "__main__":
	main()#}}}

# vim:fdm=marker
